/* eslint-disable @next/next/no-img-element */
import { CachedPlayer, SkinPart } from "mcutils-library";
import { ReactElement } from "react";
import { Card } from "../card";
import { CodeDialog } from "../code-dialog";
import { Button } from "../ui/button";
import { Separator } from "../ui/separator";
import { SkinPartImage } from "./skin-part-image";
import { CacheInformation } from "@/app/components/cache-information";

type PlayerViewProps = {
  /**
   * The player to display.
   */
  player: CachedPlayer;
};

export function PlayerView({ player }: PlayerViewProps): ReactElement {
  return (
    <div className="flex flex-col gap-2 items-center">
      <Card classNameContent="w-max xs:w-fit">
        <div className="flex gap-4 flex-col xs:flex-row relative">
          <div className="flex items-center flex-col">
            <SkinPartImage playerName={player.username} part={SkinPart.HEAD} url={player.skin.parts.head} size={96} />
          </div>

          <div className="flex flex-col gap-2">
            <div>
              <h2 className="text-xl text-primary font-semibold">{player.username}</h2>
              <p>{player.uniqueId}</p>
            </div>

            <Separator />

            <div className="flex flex-col gap-2">
              <p className="text-lg">Skin Parts</p>
              <div className="flex gap-2">
                {Object.entries(player.skin.parts)
                  .filter(([part]) => part !== SkinPart.HEAD) // Don't show the head part again
                  .map(([part, url]) => {
                    return <SkinPartImage key={part} playerName={player.username} part={part as SkinPart} url={url} />;
                  })}
              </div>
            </div>
          </div>
        </div>
      </Card>
      <div className="flex gap-2">
        <CodeDialog
          title="Player Data"
          description="The player's data from the API"
          code={JSON.stringify(player, undefined, 2)}
        >
          <Button>View as JSON</Button>
        </CodeDialog>
        <CacheInformation cache={player.cache}>
          <Button>Cache Information</Button>
        </CacheInformation>
      </div>
    </div>
  );
}
