import { CachedBedrockMinecraftServer, CachedJavaMinecraftServer } from "mcutils-library";
import Image from "next/image";
import { ReactElement } from "react";
import { Card } from "../card";
import { CodeDialog } from "../code-dialog";
import { Button } from "../ui/button";
import config from "@root/config.json";
import { cn } from "@/common/utils";
import { minecraft } from "@/app/font/fonts";
import { CacheInformation } from "@/app/components/cache-information";
import { Cache } from "mcutils-library";

type ServerViewProps = {
  /**
   * The server to display.
   */
  server: CachedJavaMinecraftServer | CachedBedrockMinecraftServer;

  /**
   * The favicon for the server.
   */
  favicon: string | undefined;
};

export function ServerView({ server, favicon }: ServerViewProps): ReactElement {
  return (
    <div className="flex flex-col gap-2 items-center scale-75 xs:scale-100">
      <Card classNameContent="w-max xs:w-fit relative">
        <div
          className={cn(
            "w-[31rem] relative p-2 flex gap-2 rounded-lg pointer-events-none",
            'bg-[url("/media/server-background.png")]',
          )}
        >
          {/* Favicon */}
          <Image
            src={favicon || `${config.apiUrl}/server/icon/fallback`}
            alt={`${server.hostname}'s Favicon`}
            width={64}
            height={64}
          />

          {/* Name & MOTD */}
          <div className={cn("flex flex-col leading-[1.3rem] w-full", minecraft.className)}>
            <h1>{server.hostname}</h1>
            {server.motd.html.map((line: string, index: number): ReactElement => {
              return <p key={index} className="pointer-events-auto" dangerouslySetInnerHTML={{ __html: line }}></p>;
            })}
          </div>

          {/* Ping */}
          <div className={cn("absolute top-0.5 right-0.5 flex items-center", minecraft.className)}>
            <p>
              {server.players.online}/{server.players.max}
            </p>
            <Image src="/media/full-ping.png" alt="Ping!" width={28} height={28} />
          </div>
        </div>
      </Card>
      <div className="flex gap-2">
        <CodeDialog
          title="Server Data"
          description="The servers's data from the API"
          code={JSON.stringify(server, undefined, 2)}
        >
          <Button>View as JSON</Button>
        </CodeDialog>
        <CacheInformation cache={server.cache}>
          <Button>Cache Information</Button>
        </CacheInformation>
      </div>
    </div>
  );
}
